API
===

.. currentmodule:: ocean_data_gateway.gateway

Top-level API
-------------

.. autosummary::
    :toctree: generated/

    Gateway


Readers
-------

.. currentmodule:: ocean_data_gateway.readers

AXDS
^^^^
.. autosummary::
   :toctree: generated/
   :recursive:

   ocean_data_gateway.readers.axds.region
   ocean_data_gateway.readers.axds.stations

ERDDAP
^^^^^^
.. autosummary::
  :toctree: generated/
  :recursive:

  ocean_data_gateway.readers.erddap.region
  ocean_data_gateway.readers.erddap.stations

Local
^^^^^^
.. autosummary::
  :toctree: generated/
  :recursive:

  ocean_data_gateway.readers.local.region
  ocean_data_gateway.readers.local.stations
